@@ -62,8 +62,8 @@ get_table_colnames <- function(dm, tables = NULL, exclude_pk = TRUE) {
     pks <- dm_get_all_pks_def_impl(def)
 
     keep_colnames <-
-      pks[c("table", "pk_col")] %>%
-      set_names(c("table", "column")) %>%
+      pks[c("table", "pk_col", "autoincrement")] %>%
+      set_names(c("table", "column", "autoincrement")) %>%
       unnest_col("column", character())
 
     table_colnames <-
